@@ -26,10 +26,10 @@ package fa_code;
 #
 ################################################################
 
-use strict;
-use warnings;
 our $test=0;our $timeout=0;
 require Exporter;
+our $VERSION = 1.00;
+use warnings;
 #use threads ();
 #use Thread::Queue;
 our @ISA = qw(Exporter Net::FullAuto::FA_Core);
@@ -66,7 +66,7 @@ $timeout=90;
 ##############################################
 
 ######## SET PASSWORD FILE LOCATION  #########
-if ($^O eq 'cygwin') {
+if ($OS eq 'cygwin') {
    $passwd_file_loc="/passwds_ms";
 } else {
    $passwd_file_loc="/passwds_ux"
